Crate pnet_sys_bandwhich_fork

Structs

FileDesc
Any file descriptor on unix, only sockets on Windows.

Constants

AF_INET
AF_INET6
IFF_BROADCAST
IFF_LOOPBACK
IFF_MULTICAST
IFF_POINTOPOINT
IFF_UP
INVALID_SOCKET
IPPROTO_IP
IP_HDRINCL
IP_TTL
SOCK_RAW
SOL_SOCKET
SO_RCVTIMEO
SO_SNDTIMEO

Functions

addr_to_sockaddr
close
duration_to_timespec
Convert a Duration into a platform specific timespec.
duration_to_timeval
Convert a Duration into a platform specific timeval.
get_socket_receive_timeout
Extracts and returns a timout for reading from the socket.
getsockopt
recv_from
send_to
set_socket_receive_timeout
Set a timeout for receiving from the socket.
setsockopt
sockaddr_to_addr
socket
timespec_to_duration
Convert a platform specific timespec into a Duration.
timeval_to_duration
Convert a platform specific timeval into a Duration.

Type Aliases

Buf
BufLen
CSocket
CouldFail
In6Addr
InAddr
MutBuf
MutSockLen
SockAddr
SockAddrFamily
SockAddrFamily6
SockAddrIn
SockAddrIn6
SockAddrStorage
SockLen
TvUsecType